# Security Policy

## Supported Versions
| Version | Supported          |Notes|
| ------- | ------------------ |-----|
| 0.1.x   | :white_check_mark: |Currently Supported and Updated|
| 0.0.12+   | :white_check_mark: |Bug and Security Fixed Only|
| <0.0.12   | :x: |Not supported, upgrade recommended|

Versions are currently tested from Python 3.6 - 3.11 by developers, and 3.6-3.10 automatically by Github.


## Reporting a Vulnerability

Bugs, including suspected security vulnerabilities, should be reported through the Github repository's issue system.  The maintainer will review all submissions and attempt to respond and/or correct the issue in a timely manner.

For critical security issues, please open an issue with the Github tracker and also email the maintainer.
